@@ -61,6 +61,7 @@ class StateMachine(CloudFormationLintRule):
                 "Iterator",
                 "ItemsPath",
                 "ItemProcessor",
+                "ItemReader",
                 "ItemSelector",
                 "ResultPath",
                 "ResultSelector",
@@ -71,7 +72,7 @@ class StateMachine(CloudFormationLintRule):
             "Choice": ["Choices", "Default"],
             "Wait": ["Seconds", "Timestamp", "SecondsPath", "TimestampPath"],
             "Succeed": [],
-            "Fail": ["Cause", "Error"],
+            "Fail": ["Cause", "CausePath", "Error", "ErrorPath"],
             "Parallel": [
                 "Branches",
                 "ResultPath",
